Additional setup for 1.13 Jenkins

Change-Id: I11d4a33b6f18cb2bcde5c2bab5dbe4fff8818c24
diff --git a/TestON/JenkinsFile/SRJenkinsFile b/TestON/JenkinsFile/SRJenkinsFile
index 4869f1e..a583774 100644
--- a/TestON/JenkinsFile/SRJenkinsFile
+++ b/TestON/JenkinsFile/SRJenkinsFile
@@ -4,7 +4,7 @@
 
 funcs.initialize( "SR" );
 jobName = env.JOB_NAME
-funcs.additionalInitForSR( jobName.reverse().take(6).reverse() )
+funcs.additionalInitForSR( jobName )
 // This is a Jenkinsfile for a scripted pipeline for the SR tests
 def prop = null
 prop = funcs.getProperties()
@@ -31,4 +31,4 @@
     tests[ test ].call()
 }
 //funcs.generateOverallGraph( prop, SR, graph_saved_directory )
-funcs.sendResultToSlack( start,  prop[ "manualRun" ], prop[ "WikiPrefix" ] )
\ No newline at end of file
+funcs.sendResultToSlack( start,  prop[ "manualRun" ], prop[ "WikiPrefix" ] )
diff --git a/TestON/JenkinsFile/JenkinsCommonFuncs.groovy b/TestON/JenkinsFile/JenkinsCommonFuncs.groovy
index 9fb887a..578b2d8 100644
--- a/TestON/JenkinsFile/JenkinsCommonFuncs.groovy
+++ b/TestON/JenkinsFile/JenkinsCommonFuncs.groovy
@@ -46,8 +46,8 @@
   print testMachine
 }
 def fabricOn( branch ){
-  return branch == "s-1.13" ? '2' : '3'
-// Temp Fix  return branch == "master" ? '2' : '3'
+  return branch.reverse().take(4).reverse() == "1.13" ? '2' : '3'
+// Temp Fix  return branch.reverse().take(6).reverse() == "master" ? '2' : '3'
 }
 def printType(){
   echo testType;